==> beast-payment-api-1.0.0-20180119.072156-78-sources.jar: com/thebeastshop/payment/vo/redirect/PAliWapCrossBorderDirectPayReqVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.payment.vo.redirect;

import com.thebeastshop.common.BaseDO;

/**
 * @author Paul-xiong
 * @date 2017年12月12日
 * @description 支付宝WAP跨境即时支付参数
 */
public class PAliWapCrossBorderDirectPayReqVO extends BaseDO {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private String service;

	private String partner;

	private String _input_charset;

	private String return_url;

	private String notify_url;

	private String out_trade_no;

	private String subject;

	private String currency;

	private String rmb_fee;

	private String timeout_rule;

	private String body;

	private String sign;

	private String sign_type;

	private String gate_way;

	public String getService() {
		return service;
	}

	public void setService(String service) {
		this.service = service;
	}

	public String getPartner() {
		return partner;
	}

	public void setPartner(String partner) {
		this.partner = partner;
	}

	public String get_input_charset() {
		return _input_charset;
	}

	public void set_input_charset(String _input_charset) {
		this._input_charset = _input_charset;
	}

	public String getReturn_url() {
		return return_url;
	}

	public void setReturn_url(String return_url) {
		this.return_url = return_url;
	}

	public String getNotify_url() {
		return notify_url;
	}

	public void setNotify_url(String notify_url) {
		this.notify_url = notify_url;
	}

	public String getOut_trade_no() {
		return out_trade_no;
	}

	public void setOut_trade_no(String out_trade_no) {
		this.out_trade_no = out_trade_no;
	}

	public String getSubject() {
		return subject;
	}

	public void setSubject(String subject) {
		this.subject = subject;
	}

	public String getCurrency() {
		return currency;
	}

	public void setCurrency(String currency) {
		this.currency = currency;
	}

	public String getRmb_fee() {
		return rmb_fee;
	}

	public void setRmb_fee(String rmb_fee) {
		this.rmb_fee = rmb_fee;
	}

	public String getTimeout_rule() {
		return timeout_rule;
	}

	public void setTimeout_rule(String timeout_rule) {
		this.timeout_rule = timeout_rule;
	}

	public String getBody() {
		return body;
	}

	public void setBody(String body) {
		this.body = body;
	}

	public String getSign() {
		return sign;
	}

	public void setSign(String sign) {
		this.sign = sign;
	}

	public String getSign_type() {
		return sign_type;
	}

	public void setSign_type(String sign_type) {
		this.sign_type = sign_type;
	}

	public String getGate_way() {
		return gate_way;
	}

	public void setGate_way(String gate_way) {
		this.gate_way = gate_way;
	}

}

==> beast-payment-api-1.3.0-20200623.084821-14-sources.jar: com/thebeastshop/payment/vo/redirect/PAliWapCrossBorderDirectPayReqVO.java <==
/*
 * Copyright (C), 上海布鲁爱电子商务有限公司
 */
package com.thebeastshop.payment.vo.redirect;

import com.thebeastshop.common.BaseDO;

/**
 * @author Paul-xiong
 * @date 2017年12月12日
 * @description 支付宝WAP跨境即时支付参数
 */
public class PAliWapCrossBorderDirectPayReqVO extends BaseDO {

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	private String service;

	private String partner;

	private String _input_charset;

	private String return_url;

	private String notify_url;

	private String out_trade_no;

	private String subject;

	private String currency;

	private String rmb_fee;

	private String timeout_rule;

	private String body;

	private String sign;

	private String sign_type;

	private String gate_way;

	private String refer_url;

	private String product_code;

	private String trade_information;

	public String getService() {
		return service;
	}

	public void setService(String service) {
		this.service = service;
	}

	public String getPartner() {
		return partner;
	}

	public void setPartner(String partner) {
		this.partner = partner;
	}

	public String get_input_charset() {
		return _input_charset;
	}

	public void set_input_charset(String _input_charset) {
		this._input_charset = _input_charset;
	}

	public String getReturn_url() {
		return return_url;
	}

	public void setReturn_url(String return_url) {
		this.return_url = return_url;
	}

	public String getNotify_url() {
		return notify_url;
	}

	public void setNotify_url(String notify_url) {
		this.notify_url = notify_url;
	}

	public String getOut_trade_no() {
		return out_trade_no;
	}

	public void setOut_trade_no(String out_trade_no) {
		this.out_trade_no = out_trade_no;
	}

	public String getSubject() {
		return subject;
	}

	public void setSubject(String subject) {
		this.subject = subject;
	}

	public String getCurrency() {
		return currency;
	}

	public void setCurrency(String currency) {
		this.currency = currency;
	}

	public String getRmb_fee() {
		return rmb_fee;
	}

	public void setRmb_fee(String rmb_fee) {
		this.rmb_fee = rmb_fee;
	}

	public String getTimeout_rule() {
		return timeout_rule;
	}

	public void setTimeout_rule(String timeout_rule) {
		this.timeout_rule = timeout_rule;
	}

	public String getBody() {
		return body;
	}

	public void setBody(String body) {
		this.body = body;
	}

	public String getSign() {
		return sign;
	}

	public void setSign(String sign) {
		this.sign = sign;
	}

	public String getSign_type() {
		return sign_type;
	}

	public void setSign_type(String sign_type) {
		this.sign_type = sign_type;
	}

	public String getGate_way() {
		return gate_way;
	}

	public void setGate_way(String gate_way) {
		this.gate_way = gate_way;
	}

	public String getRefer_url() {
		return refer_url;
	}

	public void setRefer_url(String refer_url) {
		this.refer_url = refer_url;
	}

	public String getProduct_code() {
		return product_code;
	}

	public void setProduct_code(String product_code) {
		this.product_code = product_code;
	}

	public String getTrade_information() {
		return trade_information;
	}

	public void setTrade_information(String trade_information) {
		this.trade_information = trade_information;
	}
}
